@@ -1,28 +1,41 @@
 import json
 import logging
 import pathlib
-import sys
+import re
 import zipfile
 from collections import namedtuple
 from datetime import datetime
 from io import BytesIO, StringIO
 
+import tqdm
+
 import rebotics_sdk
 
 logger = logging.getLogger(__name__)
 
 ClassificationEntry = namedtuple('ClassificationEntry', ['label', 'feature', 'image', 'filename'])
+ImageEntry = namedtuple('ImageEntry', ['filename', 'filepath', 'order'])
+
+NUMERIC_VALUE = re.compile(r'\d+')
 
 
 class ClassificationDatabaseException(Exception):
     pass
 
 
+def extract_numeric(filename):
+    found = NUMERIC_VALUE.findall(filename)
+    if len(found) == 0:
+        raise ClassificationDatabaseException('Images name should contain numeric value that represents the order. '
+                                              'Instead of {} name was used'.format(filename))
+    return int(found[0])
+
+
 class BaseClassificationDatabasePacker(object):
     version = 0
     extension = 'zip'
 
-    def __init__(self, source=None, destination=None):
+    def __init__(self, source=None, destination=None, progress_bar=False):
         self.source = source
         self.destination = destination
         self.meta_data = {
@@ -34,6 +47,7 @@ class BaseClassificationDatabasePacker(object):
 
         if self.destination is None:
             self.destination = BytesIO()
+        self.progress_bar = progress_bar
 
     def read_lines(self, lines):
         return [x for x in lines.split('\n') if x]
@@ -126,18 +140,24 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
 
     version = 1
     extension = 'rcdb'
-    images_extensions = [
-        'jpeg', 'png', 'jpg',
-    ]
+    images_extensions = {'jpeg', 'png', 'jpg'}
 
     def extract_meta_data(self, labels_path, features_path, images_folder):
+        known_order = set()
         for f in pathlib.Path(images_folder).iterdir():
             if f.is_file():
-                for ext in self.images_extensions:
-                    if f.name.endswith(ext):
-                        self.images.append((f.name, f))
+                extension = f.suffix
+                if extension in self.images_extensions:
+                    raise ClassificationDatabaseException("Extension is not supported by packer: {}".format(f.name))
+                numeric_order = extract_numeric(f.name)
+                if numeric_order in known_order:
+                    raise ClassificationDatabaseException("Numeric order collision. {}".format(f.name))
 
-        self.images.sort(key=lambda i: i[0])  # sort by filename
+                known_order.add(numeric_order)
+                self.images.append(ImageEntry(f.name, f, numeric_order))
+
+        # repack based on the filename and it's numeric value
+        self.images.sort(key=lambda i: i.order)  # sort by numeric value of the filename
 
         with open(labels_path, 'r') as labels_io, open(features_path, 'r') as features_io:
             labels = self.read_lines(labels_io.read())
@@ -160,7 +180,7 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
 
         self.meta_data.update({
             'count': features_count,
-            'images': [str(f[0]) for f in self.images]
+            'images': [str(img.filename) for img in self.images]
         })
 
     def pack(self, labels_path, features_path, images_folder):
@@ -169,11 +189,15 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
         with self.zipfile(self.destination, mode='w') as zip_io:
             zip_io.write(labels_path, 'labels.txt')
             zip_io.write(features_path, 'features.txt')
-            for name, path in self.images:
-                zip_io.write(path, pathlib.Path('images') / name)
-
             zip_io.writestr('meta.json', json.dumps(self.meta_data))
 
+            if not self.progress_bar:
+                for img in self.images:
+                    zip_io.write(img.filepath, pathlib.Path('images') / img.filename)
+            else:
+                for img in tqdm.tqdm(self.images):
+                    zip_io.write(img.filepath, pathlib.Path('images') / img.filename)
+
         return self.destination
 
     def unpack(self):
