@@ -4,7 +4,9 @@ import logging
 import os
 import webbrowser
 from copy import copy
+from datetime import datetime
 from multiprocessing import Pool
+from pathlib import Path
 
 import click
 import pandas as pd
@@ -784,6 +786,26 @@ def reverse_planogram(ctx, target):
     click.echo("Saved into {}".format(p))
 
 
+@processing_action.command('spacial')
+@click.option('-t', '--target', type=click.Path(file_okay=True, dir_okay=True), default=None,
+              help="Save into file, if none provided, will print to STDOUT")
+@pass_rebotics_context
+def processing_spacial(ctx, target):
+    data = ctx.provider.get_spacial_data(ctx.processing_id)
+
+    if target is None:
+        # printing to STDOUT
+        click.echo(json.dumps(data, indent=2))
+        return
+
+    target = Path(target)
+    if target.is_dir():
+        target /= "spacial_{}_{}.json".format(ctx.processing_id, datetime.now().strftime("%Y-%m-%d"))
+    with open(target, 'w') as fout:
+        json.dump(data, fout)
+    click.echo("Saved into {}".format(target))
+
+
 api.add_command(shell, 'shell')
 api.add_command(roles, 'roles')
 api.add_command(configure, 'configure')
