@@ -146,6 +146,19 @@ class RetailerProvider(ReboticsBaseProvider):
             'file': input_file
         })
 
+    @remote_service('/api/v4/processing/upload/by-reference/')
+    def processing_upload_by_reference(self, file_url, input_type='image', **kwargs):
+        assert input_type in (
+            'image', 'video', 'keyframe'
+        ), "File type should one of (image|video|keyframe) not %s" % input_type
+
+        return self.session.post(
+            data={
+                'input_type': input_type,
+                'ref_url': file_url
+            }
+        )
+
     @remote_service('/api/v4/export/products/')
     def export_products(self, products_filter=None, page=1):
         params = {
